==> dasu_4.11.jar: edu/northwestern/dasu/measurement/scheduler/LimitedQuotaQueue.java <==
/**
 * Dasu Project
 *
 * File:         LimitedQuotaQueue.java
 * RCS:          $Id: LimitedQuotaQueue.java,v 1.0 Apr 17, 2012 12:22:52 PM mas939 Exp $
 * Description:  QuotaQueue class (see below)
 * Author:       John Otto
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Apr 17, 2012 at 12:22:52 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.measurement.scheduler
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2012, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.measurement.scheduler;

/**
 * @author John Otto &lt;jotto@eecs.northwestern.edu&gt;
 *
 * The LimitedQuotaQueue class ...
 */

public class LimitedQuotaQueue extends QuotaQueue {
	// Only allows admission to the queue if the first task is
	// schedulable.
	
	public LimitedQuotaQueue(int maxPerMin, int maxPerHour) {
		super(maxPerMin, maxPerHour);
	}

	@Override
	public boolean admittable() {
		return schedulable();
	}
	
}

==> dasu_5.31.jar: edu/northwestern/dasu/measurement/scheduler/LimitedQuotaQueue.java <==
/**
 * Dasu Project
 *
 * File:         LimitedQuotaQueue.java
 * RCS:          $Id: LimitedQuotaQueue.java,v 1.0 Apr 17, 2012 12:22:52 PM mas939 Exp $
 * Description:  QuotaQueue class (see below)
 * Author:       John Otto
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Apr 17, 2012 at 12:22:52 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.measurement.scheduler
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2012, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.measurement.scheduler;

import edu.northwestern.dasu.measurement.tasks.DasuSubTask;
import edu.northwestern.dasu.measurement.tasks.DasuTask;

/**
 * @author John Otto &lt;jotto@eecs.northwestern.edu&gt;
 *
 * The LimitedQuotaQueue class ...
 */

public class LimitedQuotaQueue<T extends DasuTask<S>, S extends DasuSubTask> extends QuotaQueue<T,S> {
	// Only allows admission to the queue if the max size of the queue is not exceeded
	
	private int MAX_QUEUE_SIZE = 4000; 
	
	public LimitedQuotaQueue(int maxPerMin, int maxPerHour) {
		super(maxPerMin, maxPerHour);
	}
	
	public LimitedQuotaQueue(int maxPerMin, int maxPerHour, int maxQueueSize) {
		super(maxPerMin, maxPerHour);
		MAX_QUEUE_SIZE = maxQueueSize;
	}


	public LimitedQuotaQueue(int maxPerMin, int maxPerHour, int maxQueueSize, int delayCacheSize) {
		super(maxPerMin, maxPerHour, delayCacheSize);
		MAX_QUEUE_SIZE = maxQueueSize;
	}

	@Override
	public boolean admittable() {		
		return ( size() <= MAX_QUEUE_SIZE);
	}
	
}
